@@ -1,16 +1,18 @@
 from collections import defaultdict
 
 from sqlglot import alias, exp
+from sqlglot.optimizer.qualify_columns import Resolver
 from sqlglot.optimizer.scope import Scope, traverse_scope
+from sqlglot.schema import ensure_schema
 
 # Sentinel value that means an outer query selecting ALL columns
 SELECT_ALL = object()
 
 # Selection to use if selection list is empty
-DEFAULT_SELECTION = alias("1", "_")
+DEFAULT_SELECTION = lambda: alias("1", "_")
 
 
-def pushdown_projections(expression):
+def pushdown_projections(expression, schema=None, remove_unused_selections=True):
     """
     Rewrite sqlglot AST to remove unused columns projections.
 
@@ -23,34 +25,41 @@ def pushdown_projections(expression):
 
     Args:
         expression (sqlglot.Expression): expression to optimize
+        remove_unused_selections (bool): remove selects that are unused
     Returns:
         sqlglot.Expression: optimized expression
     """
     # Map of Scope to all columns being selected by outer queries.
+    schema = ensure_schema(schema)
     referenced_columns = defaultdict(set)
-    left_union = None
-    right_union = None
+
     # We build the scope tree (which is traversed in DFS postorder), then iterate
     # over the result in reverse order. This should ensure that the set of selected
     # columns for a particular scope are completely build by the time we get to it.
     for scope in reversed(traverse_scope(expression)):
         parent_selections = referenced_columns.get(scope, {SELECT_ALL})
 
-        if scope.expression.args.get("distinct"):
-            # We can't remove columns SELECT DISTINCT nor UNION DISTINCT
+        if scope.expression.args.get("distinct") or scope.parent and scope.parent.pivots:
+            # We can't remove columns SELECT DISTINCT nor UNION DISTINCT. The same holds if
+            # we select from a pivoted source in the parent scope.
             parent_selections = {SELECT_ALL}
 
         if isinstance(scope.expression, exp.Union):
-            left_union, right_union = scope.union_scopes
-            referenced_columns[left_union] = parent_selections
-            referenced_columns[right_union] = parent_selections
+            left, right = scope.union_scopes
+            referenced_columns[left] = parent_selections
 
-        if isinstance(scope.expression, exp.Select) and scope != right_union:
-            removed_indexes = _remove_unused_selections(scope, parent_selections)
-            # The left union is used for column names to select and if we remove columns from the left
-            # we need to also remove those same columns in the right that were at the same position
-            if scope is left_union:
-                _remove_indexed_selections(right_union, removed_indexes)
+            if any(select.is_star for select in right.expression.selects):
+                referenced_columns[right] = parent_selections
+            elif not any(select.is_star for select in left.expression.selects):
+                referenced_columns[right] = [
+                    right.expression.selects[i].alias_or_name
+                    for i, select in enumerate(left.expression.selects)
+                    if SELECT_ALL in parent_selections or select.alias_or_name in parent_selections
+                ]
+
+        if isinstance(scope.expression, exp.Select):
+            if remove_unused_selections:
+                _remove_unused_selections(scope, parent_selections, schema)
 
             # Group columns by source name
             selects = defaultdict(set)
@@ -68,8 +77,7 @@ def pushdown_projections(expression):
     return expression
 
 
-def _remove_unused_selections(scope, parent_selections):
-    removed_indexes = []
+def _remove_unused_selections(scope, parent_selections, schema):
     order = scope.expression.args.get("order")
 
     if order:
@@ -80,31 +88,33 @@ def _remove_unused_selections(scope, parent_selections):
 
     new_selections = []
     removed = False
-    for i, selection in enumerate(scope.selects):
-        if (
-            SELECT_ALL in parent_selections
-            or selection.alias_or_name in parent_selections
-            or selection.alias_or_name in order_refs
-        ):
+    star = False
+
+    for selection in scope.expression.selects:
+        name = selection.alias_or_name
+
+        if SELECT_ALL in parent_selections or name in parent_selections or name in order_refs:
             new_selections.append(selection)
         else:
-            removed_indexes.append(i)
+            if selection.is_star:
+                star = True
             removed = True
 
+    if star:
+        resolver = Resolver(scope, schema)
+        names = {s.alias_or_name for s in new_selections}
+
+        for name in sorted(parent_selections):
+            if name not in names:
+                new_selections.append(
+                    alias(exp.column(name, table=resolver.get_table(name)), name, copy=False)
+                )
+
     # If there are no remaining selections, just select a single constant
     if not new_selections:
-        new_selections.append(DEFAULT_SELECTION.copy())
+        new_selections.append(DEFAULT_SELECTION())
+
+    scope.expression.select(*new_selections, append=False, copy=False)
 
-    scope.expression.set("expressions", new_selections)
     if removed:
         scope.clear_cache()
-    return removed_indexes
-
-
-def _remove_indexed_selections(scope, indexes_to_remove):
-    new_selections = [
-        selection for i, selection in enumerate(scope.selects) if i not in indexes_to_remove
-    ]
-    if not new_selections:
-        new_selections.append(DEFAULT_SELECTION.copy())
-    scope.expression.set("expressions", new_selections)
