@@ -354,6 +354,12 @@ a + 4;
 a + (1 + 1) + (10);
 a + 12;
 
+a + (1 * 1) + (1 - (1 * 1));
+a + 1;
+
+a + (b * c) + (d - (e * f));
+a + b * c + (d - e * f);
+
 5 + 4 * 3;
 17;
 
